@@ -1,32 +1,14 @@
 use anyhow::{anyhow, Context, Result};
-use serde::Deserialize;
 
+use crate::cmds::issue::{generate_basic_issue_builder, Issue};
 use crate::config;
-use crate::gitlab::{Client, IssueBuilder, Query};
+use crate::gitlab::{Client, Query};
 use crate::gitlab::Issue as GLIssue;
 use crate::utils;
 
-#[derive(Debug, Deserialize)]
-struct Issue {
-    web_url: String,
-}
-
-pub fn generate_issue_builder<'a>(
-    args: &'a clap::ArgMatches,
-    config: &'a config::Config,
-    i: &'a mut IssueBuilder<'a>,
-) -> Result<GLIssue<'a>> {
-
-    let project_id = utils::get_proj_from_arg_or_conf(&args, &config)?;
-    i.project(project_id);
-    i.issue(args.value_of("id").unwrap().parse::<u64>().unwrap());
-    i.build()
-        .map_err(|e| anyhow!("Could not construct query to fetch project URL from server.\n {}",e))
-}
-
 pub fn open_issue_cmd(args: clap::ArgMatches, config: config::Config, gitlabclient: Client) -> Result<()> {
     let mut p = GLIssue::builder();
-    let endpoint = generate_issue_builder(&args, &config, &mut p)?;
+    let endpoint = generate_basic_issue_builder(&args, &config, &mut p)?;
 
     debug!("args: {:#?}", args);
     debug!("endpoint: {:#?}", endpoint);
